pub struct DropTable {
pub table_name: ValueOrGlob<String>,
}Expand description
Selector for DROP TABLE statements.
String syntax examples
DropTable– any table.DropTable(Students)– onlyStudents.
Fields
table_name: ValueOrGlob<String>The name of the table being dropped, or * for any.
Implementations
Sourceimpl DropTable
impl DropTable
Sourcepub fn new(table_name: impl Into<ValueOrGlob<String>>) -> Self
pub fn new(table_name: impl Into<ValueOrGlob<String>>) -> Self
Creates a new DropTable with the provided field values.
Each argument accepts any type that implements Into<ValueOrGlob<T>>, so callers can pass a raw value, a ValueOrGlob, or an Option<T>.
Sourcepub fn with_table_name(self, value: impl Into<ValueOrGlob<String>>) -> Self
pub fn with_table_name(self, value: impl Into<ValueOrGlob<String>>) -> Self
Sets DropTable::table_name and returns self for method chaining.
The name of the table being dropped, or * for any.
Sourcepub const fn is_all_glob(&self) -> bool
pub const fn is_all_glob(&self) -> bool
Sourcepub const fn is_all_value(&self) -> bool
pub const fn is_all_value(&self) -> bool
Sourcepub const fn is_any_glob(&self) -> bool
pub const fn is_any_glob(&self) -> bool
Sourcepub const fn is_any_value(&self) -> bool
pub const fn is_any_value(&self) -> bool
Sourcepub const fn specificity(&self) -> usize
pub const fn specificity(&self) -> usize