Module mcp

Module mcp 

MCP server implementation for SQLite.

Structs

McpServerSqlite
The MCP server instance that handles tool calls against a SQLite database with access control.

Enums

ConnectionError
Errors that can occur when checking out and configuring a pooled database connection.