pub struct WalCheckpointInfo {
pub busy: i64,
pub log_pages: i64,
pub checkpointed_pages: i64,
}Expand description
Information from a passive WAL checkpoint, as returned by PRAGMA wal_checkpoint(PASSIVE).
Fields
busy: i64Non-zero if the checkpoint was blocked by a concurrent reader or writer.
log_pages: i64The number of pages in the WAL log file.
checkpointed_pages: i64The number of pages successfully checkpointed back to the main database file.