pub enum VacuumError {
Vacuum {
source: Error,
},
}Expand description
Errors specific to the vacuum tool.
Variants
Vacuum
SQLite failed to execute the VACUUM command. This can happen if the database is locked by another connection or if there is insufficient disk space.