MCP server implementation for SQLite.
Structs
- McpServer
Sqlite - The MCP server instance that handles tool calls against a SQLite database with access control.
Enums
- Connection
Error - Errors that can occur when checking out and configuring a pooled database connection.